@@ -2,13 +2,14 @@ package WebService::MinFraud::Model::Factors;
 
 use Moo;
 
-our $VERSION = '1.002000';
+our $VERSION = '1.003000';
 
 use Types::Standard qw( HashRef InstanceOf );
 use WebService::MinFraud::Record::BillingAddress;
 use WebService::MinFraud::Record::Country;
 use WebService::MinFraud::Record::CreditCard;
 use WebService::MinFraud::Record::Device;
+use WebService::MinFraud::Record::Disposition;
 use WebService::MinFraud::Record::Email;
 use WebService::MinFraud::Record::IPAddress;
 use WebService::MinFraud::Record::Issuer;
@@ -25,6 +26,7 @@ __PACKAGE__->_define_model_attributes(
     billing_address  => 'BillingAddress',
     credit_card      => 'CreditCard',
     device           => 'Device',
+    disposition      => 'Disposition',
     email            => 'Email',
     ip_address       => 'IPAddress',
     shipping_address => 'ShippingAddress',
@@ -45,7 +47,7 @@ WebService::MinFraud::Model::Factors - Model class for minFraud Factors
 
 =head1 VERSION
 
-version 1.002000
+version 1.003000
 
 =head1 SYNOPSIS
 
@@ -100,6 +102,11 @@ Returns a L<WebService::MinFraud::Record::Device> object representing the
 device that MaxMind believes is associated with the IP address passed in the
 request.
 
+=head2 disposition
+
+Returns a L<WebService::MinFraud::Record::Disposition> object representing the
+disposition set for the transaction using custom rules.
+
 =head2 funds_remaining
 
 Returns the  I<approximate> US dollar value of the funds remaining on your
