@@ -2,8 +2,9 @@ package WebService::MinFraud::Model::Score;
 
 use Moo;
 
-our $VERSION = '1.002000';
+our $VERSION = '1.003000';
 
+use WebService::MinFraud::Record::Disposition;
 use WebService::MinFraud::Record::ScoreIPAddress;
 
 with 'WebService::MinFraud::Role::HasCommonAttributes',
@@ -11,7 +12,8 @@ with 'WebService::MinFraud::Role::HasCommonAttributes',
     'WebService::MinFraud::Role::Model';
 
 __PACKAGE__->_define_model_attributes(
-    ip_address => 'ScoreIPAddress',
+    disposition => 'Disposition',
+    ip_address  => 'ScoreIPAddress',
 );
 
 1;
@@ -28,7 +30,7 @@ WebService::MinFraud::Model::Score - Model class for minFraud: Score
 
 =head1 VERSION
 
-version 1.002000
+version 1.003000
 
 =head1 SYNOPSIS
 
@@ -57,6 +59,11 @@ documentation|https://dev.maxmind.com/minfraud/>.
 
 This class provides the following methods:
 
+=head2 disposition
+
+Returns a L<WebService::MinFraud::Record::Disposition> object representing the
+disposition set for the transaction using custom rules.
+
 =head2 funds_remaining
 
 Returns the  I<approximate> US dollar value of the funds remaining on your
